@@ -1,6 +1,17 @@
 /*
- * Translated by Nina
- * This source code is under public domain
+ * Copyright 2014 Yuichiro Moriguchi
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package net.morilib.deculture.parser;
@@ -12,6 +23,8 @@ import net.morilib.automata.lr.Terminal;
 import net.morilib.deculture.misc.CharacterTerminal;
 import net.morilib.deculture.misc.ConstantTerminal;
 
+/**
+ */
 public  class DecultureDefinition   {
 
 	static class TokenException extends RuntimeException {
@@ -27,13 +40,13 @@ public  class DecultureDefinition   {
 		abstract int stateSize();
 		abstract int finallyState();
 	}
+	private static final int NINA_BEGIN = -2;
 	private static final int NINA_EOF = -1;
 	private static final int NINA_ACCEPT = -8;
 	private static final int NINA_FAIL = -9;
 	private static final int NINA_HALT_ACCEPT = -91;
 	private static final int NINA_HALT_REJECT = -72;
 	private static final int NINA_YIELD = -85;
-	private static final int NINA_BEGIN = -2;
 	private static final int NINA_STACKLEN = 72;
 	static final int INITIAL = 0;
 
@@ -42,12 +55,22 @@ public  class DecultureDefinition   {
 	private Engine[] __stk = new Engine[NINA_STACKLEN];
 	private Object[][] __stv = new Object[NINA_STACKLEN][];
 	private int __slen = 0;
-
 	private int unread = -1;
+
+	Object _;
+	java.util.List<Object> _l;
 	Object yieldObject;
 	java.io.Reader befstream = null;
 	Throwable exception;
 
+	void _initlist() {
+		_l = new java.util.ArrayList<Object>();
+	}
+
+	void _addlist(Object x) {
+		_l.add(x);
+	}
+
 	private int __lookahead_state;
 	private int __lookahead_mark = -1;
 	private int[] __lookahead = null;
@@ -296,51 +319,63 @@ public  class DecultureDefinition   {
 			}
 			return 0;
 		case 17:
-			if($c == '>') {
+			if($c == '<') {
 				STATE = 18;
 				return 1;
+			} else if($c == '>') {
+				STATE = 19;
+				return 1;
 			} else if($c >= 0) {
 				STATE = 17;
 				return 1;
 			}
 			return 0;
-		case 18:
+		case 19:
 			if($c >= 9 && $c <= 13) {
-				STATE = 18;
+				STATE = 19;
 				return 1;
 			} else if($c == ' ') {
-				STATE = 18;
-				return 1;
-			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 19;
-				return 1;
-			} else if($c >= 'a' && $c <= 'z') {
-				STATE = 19;
-				return 1;
-			}
-			return 0;
-		case 19:
-			if($c >= '0' && $c <= '9') {
 				STATE = 19;
 				return 1;
 			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 19;
+				STATE = 20;
 				return 1;
 			} else if($c >= 'a' && $c <= 'z') {
-				STATE = 19;
-				return 1;
-			} else if($c >= 0) {
-				UNGET($c);
 				STATE = 20;
 				return 1;
 			}
 			return 0;
 		case 20:
+			if($c >= '0' && $c <= '9') {
+				STATE = 20;
+				return 1;
+			} else if($c >= 'A' && $c <= 'Z') {
+				STATE = 20;
+				return 1;
+			} else if($c >= 'a' && $c <= 'z') {
+				STATE = 20;
+				return 1;
+			} else if($c >= 0) {
+				UNGET($c);
+				STATE = 21;
+				return 1;
+			}
+			return 0;
+		case 21:
 			if($c == ';') {
 				STATE = 2;
 				return 1;
 			} else if($c >= 0) {
-				STATE = 20;
+				STATE = 21;
+				return 1;
+			}
+			return 0;
+		case 18:
+			if($c == '>') {
+				STATE = 17;
+				return 1;
+			} else if($c >= 0) {
+				STATE = 18;
 				return 1;
 			}
 			return 0;
@@ -358,384 +393,390 @@ public  class DecultureDefinition   {
 			return 0;
 		case 11:
 			if($c == 'k') {
-				STATE = 21;
-				return 1;
-			}
-			return 0;
-		case 21:
-			if($c == 'e') {
 				STATE = 22;
 				return 1;
 			}
 			return 0;
 		case 22:
-			if($c == 'n') {
+			if($c == 'e') {
 				STATE = 23;
 				return 1;
 			}
 			return 0;
 		case 23:
-			if($c >= 9 && $c <= 13) {
+			if($c == 'n') {
 				STATE = 24;
 				return 1;
-			} else if($c == ' ') {
-				STATE = 24;
-				return 1;
-			} else if($c == '<') {
-				STATE = 25;
-				return 1;
-			}
-			return 0;
-		case 25:
-			if($c == '>') {
-				STATE = 26;
-				return 1;
-			} else if($c >= 0) {
-				STATE = 27;
-				return 1;
-			}
-			return 0;
-		case 27:
-			if($c == '>') {
-				STATE = 26;
-				return 1;
-			} else if($c >= 0) {
-				STATE = 27;
-				return 1;
-			}
-			return 0;
-		case 26:
-			if($c >= 9 && $c <= 13) {
-				STATE = 26;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 26;
-				return 1;
-			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 28;
-				return 1;
-			} else if($c >= 'a' && $c <= 'z') {
-				STATE = 28;
-				return 1;
-			}
-			return 0;
-		case 28:
-			if($c >= '0' && $c <= '9') {
-				STATE = 28;
-				return 1;
-			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 28;
-				return 1;
-			} else if($c >= 'a' && $c <= 'z') {
-				STATE = 28;
-				return 1;
-			} else if($c >= 0) {
-				UNGET($c);
-				STATE = 29;
-				return 1;
-			}
-			return 0;
-		case 29:
-			if($c == ';') {
-				STATE = 2;
-				return 1;
-			} else if($c >= 0) {
-				STATE = 29;
-				return 1;
 			}
 			return 0;
 		case 24:
 			if($c >= 9 && $c <= 13) {
-				STATE = 24;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 24;
-				return 1;
-			} else if($c == '<') {
 				STATE = 25;
 				return 1;
-			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 28;
+			} else if($c == ' ') {
+				STATE = 25;
 				return 1;
-			} else if($c >= 'a' && $c <= 'z') {
+			} else if($c == '<') {
+				STATE = 26;
+				return 1;
+			}
+			return 0;
+		case 26:
+			if($c == '"') {
+				STATE = 27;
+				return 1;
+			} else if($c >= 0) {
 				STATE = 28;
 				return 1;
 			}
 			return 0;
-		case 6:
-			if($c == 't') {
+		case 28:
+			if($c == '"') {
+				STATE = 27;
+				return 1;
+			} else if($c == '<') {
+				STATE = 29;
+				return 1;
+			} else if($c == '>') {
 				STATE = 30;
 				return 1;
+			} else if($c >= 0) {
+				STATE = 28;
+				return 1;
 			}
 			return 0;
 		case 30:
-			if($c == 'a') {
+			if($c >= 9 && $c <= 13) {
+				STATE = 30;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 30;
+				return 1;
+			} else if($c >= 'A' && $c <= 'Z') {
+				STATE = 31;
+				return 1;
+			} else if($c >= 'a' && $c <= 'z') {
 				STATE = 31;
 				return 1;
 			}
 			return 0;
 		case 31:
-			if($c == 'r') {
+			if($c >= '0' && $c <= '9') {
+				STATE = 31;
+				return 1;
+			} else if($c >= 'A' && $c <= 'Z') {
+				STATE = 31;
+				return 1;
+			} else if($c >= 'a' && $c <= 'z') {
+				STATE = 31;
+				return 1;
+			} else if($c >= 0) {
+				UNGET($c);
 				STATE = 32;
 				return 1;
 			}
 			return 0;
 		case 32:
+			if($c == ';') {
+				STATE = 2;
+				return 1;
+			} else if($c >= 0) {
+				STATE = 32;
+				return 1;
+			}
+			return 0;
+		case 29:
+			if($c == '>') {
+				STATE = 28;
+				return 1;
+			} else if($c >= 0) {
+				STATE = 29;
+				return 1;
+			}
+			return 0;
+		case 27:
+			if($c == '"') {
+				STATE = 28;
+				return 1;
+			} else if($c >= 0) {
+				STATE = 27;
+				return 1;
+			}
+			return 0;
+		case 25:
+			if($c >= 9 && $c <= 13) {
+				STATE = 25;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 25;
+				return 1;
+			} else if($c == '<') {
+				STATE = 26;
+				return 1;
+			} else if($c >= 'A' && $c <= 'Z') {
+				STATE = 31;
+				return 1;
+			} else if($c >= 'a' && $c <= 'z') {
+				STATE = 31;
+				return 1;
+			}
+			return 0;
+		case 6:
 			if($c == 't') {
 				STATE = 33;
 				return 1;
 			}
 			return 0;
 		case 33:
-			if($c >= 9 && $c <= 13) {
-				STATE = 34;
-				return 1;
-			} else if($c == ' ') {
+			if($c == 'a') {
 				STATE = 34;
 				return 1;
 			}
 			return 0;
 		case 34:
-			if($c >= 9 && $c <= 13) {
-				STATE = 34;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 34;
-				return 1;
-			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 35;
-				return 1;
-			} else if($c >= 'a' && $c <= 'z') {
+			if($c == 'r') {
 				STATE = 35;
 				return 1;
 			}
 			return 0;
 		case 35:
-			if($c >= 9 && $c <= 13) {
+			if($c == 't') {
 				STATE = 36;
 				return 1;
+			}
+			return 0;
+		case 36:
+			if($c >= 9 && $c <= 13) {
+				STATE = 37;
+				return 1;
 			} else if($c == ' ') {
-				STATE = 36;
+				STATE = 37;
+				return 1;
+			}
+			return 0;
+		case 37:
+			if($c >= 9 && $c <= 13) {
+				STATE = 37;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 37;
+				return 1;
+			} else if($c >= 'A' && $c <= 'Z') {
+				STATE = 38;
+				return 1;
+			} else if($c >= 'a' && $c <= 'z') {
+				STATE = 38;
+				return 1;
+			}
+			return 0;
+		case 38:
+			if($c >= 9 && $c <= 13) {
+				STATE = 39;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 39;
 				return 1;
 			} else if($c >= '0' && $c <= '9') {
-				STATE = 35;
+				STATE = 38;
 				return 1;
 			} else if($c == ';') {
 				STATE = 2;
 				return 1;
 			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 35;
+				STATE = 38;
 				return 1;
 			} else if($c >= 'a' && $c <= 'z') {
-				STATE = 35;
+				STATE = 38;
 				return 1;
 			}
 			return 0;
-		case 36:
+		case 39:
 			if($c == ';') {
 				STATE = 2;
 				return 1;
 			} else if($c >= 0) {
-				STATE = 36;
+				STATE = 39;
 				return 1;
 			}
 			return 0;
 		case 5:
 			if(__l__ && $c == 'i') {
 				LOOKAHEAD($c);
-				STATE = 37;
-				return 1;
-			}
-			return 0;
-		case 37:
-			if(__l__ && $c == 'g') {
-				LOOKAHEAD($c);
-				STATE = 38;
-				return 1;
-			}
-			return 0;
-		case 38:
-			if(__l__ && $c == 'h') {
-				LOOKAHEAD($c);
-				STATE = 39;
-				return 1;
-			}
-			return 0;
-		case 39:
-			if($c == 't') {
-				LOOKAHEAD_COMMIT();
 				STATE = 40;
 				return 1;
 			}
 			return 0;
 		case 40:
-			if($c >= 9 && $c <= 13) {
-				STATE = 41;
-				return 1;
-			} else if($c == ' ') {
+			if(__l__ && $c == 'g') {
+				LOOKAHEAD($c);
 				STATE = 41;
 				return 1;
 			}
 			return 0;
 		case 41:
-			if($c >= 9 && $c <= 13) {
-				STATE = 41;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 41;
-				return 1;
-			} else if($c == '\'') {
+			if(__l__ && $c == 'h') {
+				LOOKAHEAD($c);
 				STATE = 42;
 				return 1;
-			} else if($c == ';') {
-				STATE = 2;
-				return 1;
-			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 43;
-				return 1;
-			} else if($c >= 'a' && $c <= 'z') {
+			}
+			return 0;
+		case 42:
+			if($c == 't') {
+				LOOKAHEAD_COMMIT();
 				STATE = 43;
 				return 1;
 			}
 			return 0;
 		case 43:
 			if($c >= 9 && $c <= 13) {
-				STATE = 41;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 41;
-				return 1;
-			} else if($c >= '0' && $c <= '9') {
-				STATE = 43;
-				return 1;
-			} else if($c == ';') {
 				STATE = 44;
 				return 1;
-			} else if($c >= 'A' && $c <= 'Z') {
-				STATE = 43;
-				return 1;
-			} else if($c >= 'a' && $c <= 'z') {
-				STATE = 43;
+			} else if($c == ' ') {
+				STATE = 44;
 				return 1;
 			}
 			return 0;
 		case 44:
+			if($c >= 9 && $c <= 13) {
+				STATE = 44;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 44;
+				return 1;
+			} else if($c == '\'') {
+				STATE = 45;
+				return 1;
+			} else if($c == ';') {
+				STATE = 2;
+				return 1;
+			} else if($c >= 'A' && $c <= 'Z') {
+				STATE = 46;
+				return 1;
+			} else if($c >= 'a' && $c <= 'z') {
+				STATE = 46;
+				return 1;
+			}
+			return 0;
+		case 46:
+			if($c >= 9 && $c <= 13) {
+				STATE = 44;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 44;
+				return 1;
+			} else if($c >= '0' && $c <= '9') {
+				STATE = 46;
+				return 1;
+			} else if($c == ';') {
+				STATE = 47;
+				return 1;
+			} else if($c >= 'A' && $c <= 'Z') {
+				STATE = 46;
+				return 1;
+			} else if($c >= 'a' && $c <= 'z') {
+				STATE = 46;
+				return 1;
+			}
+			return 0;
+		case 47:
 			if($c >= 0) {
 				UNGET($c);
 				STATE = 2;
 				return 1;
 			}
 			return 0;
-		case 42:
+		case 45:
 			if($c == '\\') {
-				STATE = 45;
+				STATE = 48;
 				return 1;
 			} else if($c >= 0) {
-				STATE = 46;
+				STATE = 49;
 				return 1;
 			}
 			return 0;
-		case 46:
+		case 49:
 			if($c == '\'') {
+				STATE = 50;
+				return 1;
+			}
+			return 0;
+		case 50:
+			if($c >= 9 && $c <= 13) {
+				STATE = 44;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 44;
+				return 1;
+			} else if($c == ';') {
 				STATE = 47;
 				return 1;
 			}
 			return 0;
-		case 47:
-			if($c >= 9 && $c <= 13) {
-				STATE = 41;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 41;
-				return 1;
-			} else if($c == ';') {
-				STATE = 44;
-				return 1;
-			}
-			return 0;
-		case 45:
+		case 48:
 			if($c >= 0) {
-				STATE = 46;
+				STATE = 49;
 				return 1;
 			}
 			return 0;
 		case 4:
 			if(__l__ && $c == 'o') {
-				LOOKAHEAD($c);
-				STATE = 48;
-				return 1;
-			}
-			return 0;
-		case 48:
-			if(__l__ && $c == 'n') {
-				LOOKAHEAD($c);
-				STATE = 49;
-				return 1;
-			}
-			return 0;
-		case 49:
-			if(__l__ && $c == 'a') {
-				LOOKAHEAD($c);
-				STATE = 50;
-				return 1;
-			}
-			return 0;
-		case 50:
-			if(__l__ && $c == 's') {
 				LOOKAHEAD($c);
 				STATE = 51;
 				return 1;
 			}
 			return 0;
 		case 51:
-			if(__l__ && $c == 's') {
+			if(__l__ && $c == 'n') {
 				LOOKAHEAD($c);
 				STATE = 52;
 				return 1;
 			}
 			return 0;
 		case 52:
-			if(__l__ && $c == 'o') {
+			if(__l__ && $c == 'a') {
 				LOOKAHEAD($c);
 				STATE = 53;
 				return 1;
 			}
 			return 0;
 		case 53:
-			if($c == 'c') {
-				LOOKAHEAD_COMMIT();
+			if(__l__ && $c == 's') {
+				LOOKAHEAD($c);
 				STATE = 54;
 				return 1;
 			}
 			return 0;
 		case 54:
-			if($c >= 9 && $c <= 13) {
-				STATE = 41;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 41;
-				return 1;
-			}
-			return 0;
-		case 3:
-			if(__l__ && $c == 'e') {
+			if(__l__ && $c == 's') {
 				LOOKAHEAD($c);
 				STATE = 55;
 				return 1;
 			}
 			return 0;
 		case 55:
-			if(__l__ && $c == 'f') {
+			if(__l__ && $c == 'o') {
 				LOOKAHEAD($c);
 				STATE = 56;
 				return 1;
-			} else if(__l__ && $c == 'x') {
-				LOOKAHEAD($c);
+			}
+			return 0;
+		case 56:
+			if($c == 'c') {
+				LOOKAHEAD_COMMIT();
 				STATE = 57;
 				return 1;
 			}
 			return 0;
 		case 57:
+			if($c >= 9 && $c <= 13) {
+				STATE = 44;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 44;
+				return 1;
+			}
+			return 0;
+		case 3:
 			if(__l__ && $c == 'e') {
 				LOOKAHEAD($c);
 				STATE = 58;
@@ -743,74 +784,92 @@ public  class DecultureDefinition   {
 			}
 			return 0;
 		case 58:
-			if($c == 'r') {
-				LOOKAHEAD_COMMIT();
+			if(__l__ && $c == 'f') {
+				LOOKAHEAD($c);
 				STATE = 59;
 				return 1;
-			}
-			return 0;
-		case 59:
-			if($c >= 9 && $c <= 13) {
-				STATE = 60;
-				return 1;
-			} else if($c == ' ') {
+			} else if(__l__ && $c == 'x') {
+				LOOKAHEAD($c);
 				STATE = 60;
 				return 1;
 			}
 			return 0;
 		case 60:
-			if($c >= 9 && $c <= 13) {
-				STATE = 60;
-				return 1;
-			} else if($c == ' ') {
-				STATE = 60;
-				return 1;
-			} else if($c >= 0) {
+			if(__l__ && $c == 'e') {
+				LOOKAHEAD($c);
 				STATE = 61;
 				return 1;
 			}
 			return 0;
 		case 61:
-			if($c >= 0 && $c <= 8) {
-				STATE = 61;
-				return 1;
-			} else if($c >= 14 && $c <= 31) {
-				STATE = 61;
-				return 1;
-			} else if($c >= '!' && $c <= ':') {
-				STATE = 61;
-				return 1;
-			} else if($c >= '<' && $c <= 2147483647) {
-				STATE = 61;
-				return 1;
-			} else if($c >= 0) {
-				UNGET($c);
+			if($c == 'r') {
+				LOOKAHEAD_COMMIT();
 				STATE = 62;
 				return 1;
 			}
 			return 0;
 		case 62:
-			if($c == ';') {
-				STATE = 2;
+			if($c >= 9 && $c <= 13) {
+				STATE = 63;
 				return 1;
-			} else if($c >= 0) {
-				STATE = 62;
-				return 1;
-			}
-			return 0;
-		case 56:
-			if($c == 't') {
-				LOOKAHEAD_COMMIT();
+			} else if($c == ' ') {
 				STATE = 63;
 				return 1;
 			}
 			return 0;
 		case 63:
 			if($c >= 9 && $c <= 13) {
-				STATE = 41;
+				STATE = 63;
 				return 1;
 			} else if($c == ' ') {
-				STATE = 41;
+				STATE = 63;
+				return 1;
+			} else if($c >= 0) {
+				STATE = 64;
+				return 1;
+			}
+			return 0;
+		case 64:
+			if($c >= 0 && $c <= 8) {
+				STATE = 64;
+				return 1;
+			} else if($c >= 14 && $c <= 31) {
+				STATE = 64;
+				return 1;
+			} else if($c >= '!' && $c <= ':') {
+				STATE = 64;
+				return 1;
+			} else if($c >= '<' && $c <= 2147483647) {
+				STATE = 64;
+				return 1;
+			} else if($c >= 0) {
+				UNGET($c);
+				STATE = 65;
+				return 1;
+			}
+			return 0;
+		case 65:
+			if($c == ';') {
+				STATE = 2;
+				return 1;
+			} else if($c >= 0) {
+				STATE = 65;
+				return 1;
+			}
+			return 0;
+		case 59:
+			if($c == 't') {
+				LOOKAHEAD_COMMIT();
+				STATE = 66;
+				return 1;
+			}
+			return 0;
+		case 66:
+			if($c >= 9 && $c <= 13) {
+				STATE = 44;
+				return 1;
+			} else if($c == ' ') {
+				STATE = 44;
 				return 1;
 			}
 			return 0;
@@ -825,153 +884,162 @@ public  class DecultureDefinition   {
 
 	int decultureDefinition_execaction(int  $c) {
 		switch(STATE) {
-		case 30:
-			break;
-		case 31:
-			break;
-		case 46:
-			ch = $c;
-			break;
-		case 25:
-			break;
-		case 8:
-			break;
-		case 29:
-			_pt();
-			break;
-		case 45:
-			break;
-		case 10:
-			_d($c);
-			break;
-		case 13:
-			break;
-		case 36:
-			break;
-		case 16:
-			break;
-		case 6:
-			break;
-		case 43:
-			_b($c);
-			break;
-		case 18:
-			_tp();
-			break;
-		case 24:
-			break;
-		case 39:
-			break;
-		case 51:
-			break;
-		case 15:
-			break;
-		case 23:
-			_ib();
-			break;
-		case 14:
-			_ib();
-			break;
-		case 52:
-			break;
-		case 0:
+		case 2:
 			break;
 		case 19:
-			_b($c);
-			break;
-		case 1:
-			break;
-		case 63:
-			_il();
-			break;
-		case 22:
-			break;
-		case 27:
-			_b($c);
-			break;
-		case 55:
-			break;
-		case 12:
-			break;
-		case 42:
-			break;
-		case 35:
-			_s($c);
-			break;
-		case 26:
 			_tp();
 			break;
-		case 58:
-			break;
-		case 32:
-			break;
-		case 33:
-			break;
-		case 60:
-			break;
-		case 7:
-			break;
-		case 11:
-			break;
-		case 37:
-			break;
-		case 21:
-			break;
-		case 17:
-			_b($c);
-			break;
-		case 38:
-			break;
-		case 48:
-			break;
-		case 41:
-			_pa();
-			break;
-		case 49:
-			break;
-		case 54:
-			_ix();
-			break;
-		case 62:
-			break;
-		case 4:
-			break;
-		case 56:
-			break;
-		case 57:
-			break;
-		case 59:
-			break;
 		case 53:
 			break;
-		case 2:
+		case 22:
 			break;
-		case 5:
-			break;
-		case 47:
-			break;
-		case 20:
-			_pn();
-			break;
-		case 9:
+		case 33:
 			break;
 		case 34:
 			break;
-		case 40:
-			_ir();
+		case 42:
 			break;
-		case 44:
-			_pe();
+		case 24:
+			_ib();
 			break;
-		case 61:
+		case 50:
+			break;
+		case 64:
 			_l($c);
 			break;
-		case 3:
+		case 66:
+			_il();
+			break;
+		case 43:
+			_ir();
+			break;
+		case 12:
+			break;
+		case 30:
+			_tp();
+			break;
+		case 13:
+			break;
+		case 56:
+			break;
+		case 62:
 			break;
 		case 28:
 			_b($c);
 			break;
-		case 50:
+		case 49:
+			ch = $c;
+			break;
+		case 26:
+			break;
+		case 44:
+			_pa();
+			break;
+		case 10:
+			_d($c);
+			break;
+		case 40:
+			break;
+		case 65:
+			break;
+		case 29:
+			_b($c);
+			break;
+		case 5:
+			break;
+		case 38:
+			_s($c);
+			break;
+		case 7:
+			break;
+		case 45:
+			break;
+		case 57:
+			_ix();
+			break;
+		case 9:
+			break;
+		case 54:
+			break;
+		case 51:
+			break;
+		case 60:
+			break;
+		case 0:
+			break;
+		case 39:
+			break;
+		case 32:
+			_pt();
+			break;
+		case 11:
+			break;
+		case 47:
+			_pe();
+			break;
+		case 55:
+			break;
+		case 23:
+			break;
+		case 59:
+			break;
+		case 48:
+			break;
+		case 8:
+			break;
+		case 18:
+			_b($c);
+			break;
+		case 31:
+			_b($c);
+			break;
+		case 41:
+			break;
+		case 16:
+			break;
+		case 52:
+			break;
+		case 14:
+			_ib();
+			break;
+		case 36:
+			break;
+		case 37:
+			break;
+		case 58:
+			break;
+		case 27:
+			_b($c);
+			break;
+		case 46:
+			_b($c);
+			break;
+		case 4:
+			break;
+		case 17:
+			_b($c);
+			break;
+		case 25:
+			break;
+		case 6:
+			break;
+		case 1:
+			break;
+		case 15:
+			break;
+		case 20:
+			_b($c);
+			break;
+		case 61:
+			break;
+		case 63:
+			break;
+		case 35:
+			break;
+		case 3:
+			break;
+		case 21:
+			_pn();
 			break;
 		}
 		return 1;
@@ -1008,7 +1076,7 @@ public  class DecultureDefinition   {
 		}
 
 		int stateSize() {
-			return 64;
+			return 67;
 		}
 
 		int finallyState() {
