@@ -177,6 +177,7 @@ public class DFABuilder implements NinaAction {
 
 		PrintWriter out = null;
 		int devoirFermer = 0;
+		boolean emptyTrans = false;
 
 		Collection<DBS> identical = null;
 
@@ -433,7 +434,13 @@ public class DFABuilder implements NinaAction {
 
 		@Override
 		public boolean isDead() {
-			return edges == null && others == null;
+			return (edges == null && others == null && end == null &&
+					recursive == null && dynamic == null);
+		}
+
+		public boolean isOnlyEmptyTransition() {
+			return (emptyTrans && !initial &&
+					edges == null && recursive == null && dynamic == null);
 		}
 
 		@Override
@@ -549,6 +556,8 @@ public class DFABuilder implements NinaAction {
 	//
 	private static final Object _END = new Object();
 	private static final Object _FLOAT = new Object();
+	private static final Object _ID_JAVA = new Object();
+	private static final Object _ID_C = new Object();
 
 	//
 	private static final Range DIGIT =
@@ -570,6 +579,26 @@ public class DFABuilder implements NinaAction {
 	private static final Range CHAR_E =
 			IntervalsInt.newClosedInterval('e', 'e').join(
 					IntervalsInt.newClosedInterval('E', 'E'));
+	private static final Range ID_C_START =
+			IntervalsInt.newClosedInterval('A', 'Z')
+			.join(IntervalsInt.newClosedInterval('a', 'z'))
+			.join(IntervalsInt.newClosedInterval('_', '_'));
+	private static final Range ID_C_PART =
+			ID_C_START
+			.join(IntervalsInt.newClosedInterval('0', '9'));
+	private static final Range ID_JAVA_START =
+			ID_C_START
+			.join(IntervalsInt.newClosedInterval('$', '$'))
+			.join(IntervalsInt.newClosedInterval(0x80, 0xfffc));
+	private static final Range ID_JAVA_PART =
+			ID_JAVA_START
+			.join(IntervalsInt.newClosedInterval('0', '9'));
+	private static final Range NOT_WORD = CharSets.complement(
+			IntervalsInt.newClosedInterval('A', 'Z')
+			.join(IntervalsInt.newClosedInterval('a', 'z'))
+			.join(IntervalsInt.newClosedInterval('_', '_'))
+			.join(IntervalsInt.newClosedInterval('0', '9'))
+			.join(IntervalsInt.newClosedInterval(0x80, 0x7ffffffe)));
 
 	//
 	private Map<String, DBS> map = new HashMap<String, DBS>();
@@ -686,7 +715,8 @@ public class DFABuilder implements NinaAction {
 		DFA<Object, NFAState, Void> d;
 
 		try {
-			n = RegexpParser.parse(re);
+			// NFA bugs
+			n = RegexpParser.parse(re, null);
 			d = ConvertedRangeDFA.convertDFA(n);
 			_linkdfa1(q, d, x, vertex, mealy, lh, lc, false);
 		} catch (RegexParseException e) {
@@ -694,9 +724,18 @@ public class DFABuilder implements NinaAction {
 		}
 	}
 
+	private static boolean _isword(CharSequence s) {
+		for(int k = 0; k < s.length(); k++) {
+			if(NOT_WORD.contains(Integer.valueOf(s.charAt(k)))) {
+				return false;
+			}
+		}
+		return true;
+	}
+
 	private void _linkdq(NinaEvent q, CharSequence s, DBS v) {
 		List<DoubleQuoteTokenizer.Elems> b;
-		String g, lh, lm, lc;
+		String g, lh, lm, lc, lu;
 		boolean z;
 		int k, c;
 		DBS x, a;
@@ -705,6 +744,7 @@ public class DFABuilder implements NinaAction {
 		lh = q.getLanguageOption().getLookahead();
 		lm = q.getLanguageOption().getLookaheadMark();
 		lc = q.getLanguageOption().getLookaheadCommit();
+		lu = q.getLanguageOption().getUnget();
 		b  = DoubleQuoteTokenizer.parse(s.toString());
 		for(DoubleQuoteTokenizer.Elems p : b) {
 			x = v;
@@ -741,11 +781,15 @@ public class DFABuilder implements NinaAction {
 				r = Interval.newPoint(Integer.valueOf(s.charAt(k)));
 				if(p.isInvertLookahead())  r = CharSets.complement(r);
 				x.linkAlphabet(vertex, r, g);
+			} else if(_isword(s)) {
+				x = _linkc(q, x, s.charAt(k), lh);
+				g = lc + lu;
+				if(mealy != null)  g += mealy.toString();
+				x.linkAlphabet(vertex, NOT_WORD, g);
 			} else {
 				g = lc;
 				if(mealy != null)  g += mealy.toString();
 				r = Interval.newPoint(Integer.valueOf(s.charAt(k)));
-				if(p.isInvertLookahead())  r = CharSets.complement(r);
 				x.linkAlphabet(vertex, r, g);
 			}
 		}
@@ -1053,6 +1097,22 @@ public class DFABuilder implements NinaAction {
 		sepd.linkEnd(vertex, e2);
 	}
 
+	private void _linkId(NinaEvent q, DBS v, Range st, Range pa) {
+		NinaLanguageOption p = q.getLanguageOption();
+		String m, ib, ab;
+		DBS svar;
+
+		m  = mealy != null ? mealy.toString() : "";
+		ib = p.getInitBuffer(p.getSequenceBufferName());
+		ab = p.getAppendBuffer(p.getSequenceBufferName());
+
+		svar = createState(q);
+		v.linkAlphabet(svar, st, ib + ab);
+		svar.linkAlphabet(svar, pa, ab);
+		svar.linkOthers(vertex, p.getUnget() + m);
+		svar.linkEnd(vertex, m);
+	}
+
 	/* (non-Javadoc)
 	 * @see net.morilib.nina.NinaAction#link(net.morilib.nina.NinaEvent, java.lang.Object)
 	 */
@@ -1065,6 +1125,7 @@ public class DFABuilder implements NinaAction {
 		if((o = q.getEdge()) == null) {
 			v.linkOthers(vertex, q.getLanguageOption().getUnget());
 			v.linkEnd(vertex, null);
+			v.emptyTrans = true;
 		} else if(o instanceof BuildMachine) {
 			v.linkRecursive(vertex, ((BuildMachine)o).name);
 		} else if(o instanceof RT) {
@@ -1105,6 +1166,10 @@ public class DFABuilder implements NinaAction {
 			_linkFloat(q, v);
 		} else if(o == _END) {
 			v.linkEnd(vertex, mealy);
+		} else if(o == _ID_JAVA) {
+			_linkId(q, v, ID_JAVA_START, ID_JAVA_PART);
+		} else if(o == _ID_C) {
+			_linkId(q, v, ID_C_START, ID_C_PART);
 		} else {
 			v.linkAlphabet(vertex, o, mealy);
 		}
@@ -1417,4 +1482,26 @@ public class DFABuilder implements NinaAction {
 		q.setEdge(_FLOAT);
 	}
 
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeIndent(net.morilib.nina.NinaEvent, java.lang.String, int)
+	 */
+	@Override
+	public void setEdgeIndent(NinaEvent q, String cmp, int off) {
+		NinaLanguageOption p = q.getLanguageOption();
+
+		setUserEdge(q, p.getIndent(cmp, off));
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeIdentifier(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeIdentifier(NinaEvent q, String lang) {
+		if(lang.equals("Java")) {
+			q.setEdge(_ID_JAVA);
+		} else {
+			q.setEdge(_ID_C);
+		}
+	}
+
 }
