@@ -88,8 +88,8 @@ public class NinaParser {
 		ARR_N, ARR_E, ARR_S, ARR_W,
 		ARRZN, ARRZS, ARRZE, ARRZW,
 		WP_E1, WP_W1,
-		TOIX1, TOIY1,
-		SER1E, TORY1, SER11, SER1q, SER1c, SER1r, SER1b,
+		TOIX1, TOJX1, TOIx1, TOIY1, SER1E, RETP1,
+		TORY1, SER11, SER1q, SER1c, SER1r, SER1b,
 		SER1F, SER1G, SER1H,
 		SER1W, SER1Q, SER1C, SER1R, SER1B,
 		SER1X, SER1Y,
@@ -116,6 +116,19 @@ public class NinaParser {
 	private static final Pattern LD_O = Pattern.compile(
 			"01?[0-7]{1,5}");
 	private static final Pattern LD_D = Pattern.compile("[0-9]+");
+	private static final Pattern DIGI = Pattern.compile(
+			":(signed-)?digits-([1-8*])");
+	private static final Pattern DIGH = Pattern.compile(
+			":hex-(8|16|32|\\*)");
+	private static final Pattern DIGO = Pattern.compile(
+			":oct-(8|16|32|\\*)");
+	private static final Pattern INDT = Pattern.compile(
+			":indent(<=?|>=?|==|!=)([\\+\\-][0-9]+)?");
+	private static final String  FLOT = ":float";
+	private static final String  IJAV = ":identifier-Java";
+	private static final String  ID_C = ":identifier-C";
+
+	//
 	private static final String NL = System.getProperty(
 			"line.separator");
 
@@ -151,6 +164,8 @@ public class NinaParser {
 	private int quote;
 	private int chr;
 	private int counter;
+	private int regX, regY;
+	private Quadro.Direction todir;
 
 	//
 	NinaParser(Quadro q, NinaAction action,
@@ -392,6 +407,7 @@ public class NinaParser {
 		NFA<Object, NFAState, Void> n;
 		DFA<Object, NFAState, Void> d;
 		String t, v;
+		NFAState x;
 		Matcher m;
 
 		if(s.startsWith("ex:")) {
@@ -400,7 +416,55 @@ public class NinaParser {
 			action.setEdgeDynamic(q, s.substring(3));
 		} else if(s.startsWith("g:")) {
 			action.setEdgeGrammar(q, s.substring(2));
-		} else if(s.indexOf("$c") >= 0) {
+		} else if((m = DIGI.matcher(s)).matches()) {
+			if(type.equals(Character.TYPE)) {
+				if(m.group(2).equals("*")) {
+					action.setEdgeDigits(q, -1, m.group(1) != null);
+				} else {
+					action.setEdgeDigits(q,
+							Integer.parseInt(m.group(2)),
+							m.group(1) != null);
+				}
+			} else {
+				throw new NinaException(this, "invalidalphabettype");
+			}
+		} else if((m = DIGH.matcher(s)).matches()) {
+			if(type.equals(Character.TYPE)) {
+				if(m.group(1).equals("*")) {
+					action.setEdgeHexadecimal(q, -1);
+				} else {
+					action.setEdgeHexadecimal(q,
+							Integer.parseInt(m.group(1)));
+				}
+			} else {
+				throw new NinaException(this, "invalidalphabettype");
+			}
+		} else if((m = DIGO.matcher(s)).matches()) {
+			if(type.equals(Character.TYPE)) {
+				if(m.group(1).equals("*")) {
+					action.setEdgeOctal(q, -1);
+				} else {
+					action.setEdgeOctal(q,
+							Integer.parseInt(m.group(1)));
+				}
+			} else {
+				throw new NinaException(this, "invalidalphabettype");
+			}
+		} else if((m = INDT.matcher(s)).matches()) {
+			if((t = m.group(2)) == null) {
+				action.setEdgeIndent(q, m.group(1), 0);
+			} else {
+				t = t.replaceFirst("^\\+", "");
+				action.setEdgeIndent(q, m.group(1),
+						Integer.parseInt(t));
+			}
+		} else if(s.equals(FLOT)) {
+			action.setEdgeFloat(q);
+		} else if(s.equals(IJAV)) {
+			action.setEdgeIdentifier(q, "Java");
+		} else if(s.equals(ID_C)) {
+			action.setEdgeIdentifier(q, "C");
+		} else if(s.indexOf("$c") >= 0 || s.indexOf("__c__") >= 0) {
 			action.setUserEdge(q, s);
 		} else if((m = ANYS.matcher(s)).matches()) {
 			action.setEdgeSequence(q, null,
@@ -428,7 +492,8 @@ public class NinaParser {
 					t.charAt(t.length() - 1) == '`') {
 				try {
 					t = t.substring(1, t.length() - 1);
-					n = RegexpParser.parse(t);
+					x = new NFAState() {};
+					n = RegexpParser.parse(t, x);
 					d = ConvertedRangeDFA.convertDFA(n);
 					action.setEdgeRepeatedResource(q, v, d);
 				} catch (RegexParseException e) {
@@ -464,6 +529,7 @@ public class NinaParser {
 	private void metBordLabel(String l) {
 		NFA<Object, NFAState, Void> nz;
 		Set<String> d;
+		NFAState z;
 		Matcher m;
 		String s;
 
@@ -491,7 +557,8 @@ public class NinaParser {
 				return;
 			} else if((m = LB_R.matcher(s)).matches()) {
 				try {
-					nz = RegexpParser.parse(m.group(1));
+					z  = new NFAState() {};
+					nz = RegexpParser.parse(m.group(1), z);
 					metBordNFA(nz);
 					return;
 				} catch(RegexParseException e) {
@@ -590,6 +657,7 @@ public class NinaParser {
 		StringBuffer bt;
 		NinaAction n;
 		String s, t;
+		NFAState dm;
 		Object o;
 		int c;
 		S z;
@@ -1132,6 +1200,7 @@ public class NinaParser {
 			} else if(q.get() == '<') {
 				q.set('*');
 				q.east();
+				nestlv = 1;
 				etat = S.FI_L4;
 			} else if(q.isFrameBefore() || q.isArrow()) {
 				q.west();
@@ -1163,6 +1232,7 @@ public class NinaParser {
 				bf2 = new StringBuffer();
 				q.set('*');
 				q.east();
+				nestlv = 1;
 				etat = S.FI_L4;
 			} else if(q.get() >= 0) {
 				buf.appendCodePoint(q.get());
@@ -1173,11 +1243,14 @@ public class NinaParser {
 			}
 			break;
 		case FI_L4:
-			if(q.get() == '>') {
+			if(q.get() == '>' && --nestlv <= 0) {
 				q.set('*');
 				q.west();
 				etat = S.FI_L2;
 			} else if(q.get() >= 0) {
+				if(q.get() == '<') {
+					nestlv++;
+				}
 				bf2.appendCodePoint(q.get());
 				q.set('*');
 				q.east();
@@ -2051,7 +2124,8 @@ public class NinaParser {
 				etat = S.AR_Eg;
 			} else if(q.get() == '`') {
 				try {
-					nz = RegexpParser.parse(buf.toString());
+					dm = new NFAState() {};
+					nz = RegexpParser.parse(buf.toString(), dm);
 					metBordNFA(nz);
 				} catch(RegexParseException e) {
 					throw new NinaException(this, "invalidregex");
@@ -2782,7 +2856,8 @@ public class NinaParser {
 				etat = S.AR_WG;
 			} else {
 				try {
-					nz = RegexpParser.parse(buf.reverse().toString());
+					dm = new NFAState() {};
+					nz = RegexpParser.parse(buf.reverse().toString(), dm);
 					metBordNFA(nz);
 				} catch (RegexParseException e) {
 					throw new NinaException(this, "invalidregex");
@@ -2882,7 +2957,7 @@ public class NinaParser {
 			if(q.get() == '(') {
 				buf.reverse();
 				q.set(Quadro.WARP2);
-				etat = S.TOIX1;
+				etat = S.TOJX1;
 			} else if(q.get() >= 0) {
 				buf.appendCodePoint(q.get());
 				q.west();
@@ -3462,6 +3537,18 @@ public class NinaParser {
 			}
 			break;
 		case TOIX1:
+			regX = q.getX();
+			regY = q.getY();
+			etat = S.TOIx1;
+			todir = Quadro.Direction.WEST;
+			break;
+		case TOJX1:
+			regX = q.getX();
+			regY = q.getY();
+			etat = S.TOIx1;
+			todir = Quadro.Direction.EAST;
+			break;
+		case TOIx1:
 			if(q.isBlankX()) {
 				q.east();
 				etat = S.TOIY1;
@@ -3489,13 +3576,33 @@ public class NinaParser {
 			} else {
 				action.link(q, o = q.getScratch());
 				if(o != null) {
-					etat = S.TOIX2;
+//					etat = S.TOIX2;
+					q.setPosition(regX, regY);
+					q.set(Quadro.WARP3);
+					q.west();
+					etat = S.RETP1;
 				} else {
 					q.setVisiting(buf.toString());
 					etat = S.LBLE;
 				}
 			}
 			break;
+		case RETP1:
+			// return position
+			if(q.get() == Quadro.WARP2) {
+				q.set(Quadro.WARP3);
+//				q.west();
+				q.move(todir);
+				etat = todir.equals(Quadro.Direction.WEST) ?
+						S.ARR_W : S.ARR_E;
+			} else if(q.isBlankX()) {
+				throw new NinaException(this, "labelnotfound",
+						buf.toString());
+			} else {
+//				q.west();
+				q.move(todir);
+			}
+			break;
 		case TORY1:
 			if(q.isBlankY() || q.get() == '#') {
 				q.south();
