@@ -15,10 +15,12 @@
  */
 package net.morilib.nina.translate;
 
+import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.PrintStream;
 import java.io.Reader;
+import java.text.SimpleDateFormat;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.IdentityHashMap;
@@ -31,14 +33,18 @@ import net.morilib.automata.DFA;
 import net.morilib.automata.DFAState;
 import net.morilib.automata.dfa.ConvertedDFA;
 import net.morilib.automata.dfa.ConvertedRangeDFA;
-import net.morilib.automata.dfa.MinimizedRangeDFA;
 import net.morilib.nina.DFABuilder;
+import net.morilib.nina.DFABuilder.DBS;
 import net.morilib.nina.NFABuilder;
 import net.morilib.nina.Nina;
 import net.morilib.nina.NinaAction;
+import net.morilib.nina.NinaException;
 import net.morilib.nina.NinaNFA;
 import net.morilib.nina.NinaParser;
+import net.morilib.nina.NinaSubautomata;
 import net.morilib.nina.Quadro;
+import net.morilib.nina.TMBuilder;
+import net.morilib.nina.cmd.NinaInfo;
 import net.morilib.nina.cmd.NinatOptions;
 import net.morilib.nina.metalang.NinaMetaLanguage;
 import net.morilib.nina.translate.sh.ShNinatBuiltInCommands;
@@ -49,6 +55,7 @@ import net.morilib.sh.ShFacade;
 import net.morilib.sh.ShFileSystem;
 import net.morilib.sh.ShProcess;
 import net.morilib.sh.ShRootEnvironment;
+import net.morilib.sh.ShRootShellEnvironment;
 import net.morilib.sh.ShRuntime;
 import net.morilib.sh.ShSyntaxException;
 import net.morilib.sh.misc.XtraceStream;
@@ -61,6 +68,10 @@ import net.morilib.sh.misc.XtraceStream;
 public abstract class AbstractNinaTranslator
 implements NinaTranslator {
 
+	//
+	private static final SimpleDateFormat YEAR =
+			new SimpleDateFormat("yyyy");
+
 	/**
 	 * 
 	 */
@@ -79,7 +90,12 @@ implements NinaTranslator {
 	/**
 	 * 
 	 */
-	protected NinatOptions options;
+	protected NinaInfo options;
+
+	/**
+	 * 
+	 */
+	protected AbstractNinaTranslator parent;
 
 	//
 	private int stateNo = 0;
@@ -87,6 +103,8 @@ implements NinaTranslator {
 			new IdentityHashMap
 			<DFAState<Object, ?, Void>, Integer>();
 	private Set<Integer> accepts = new HashSet<Integer>();
+	private Set<Integer> deads = new HashSet<Integer>();
+	private Set<Integer> emptyTransitions = new HashSet<Integer>();
 	private Stack<DFAState<Object, ?, Void>> trz =
 			new Stack<DFAState<Object, ?, Void>>();
 
@@ -122,6 +140,21 @@ implements NinaTranslator {
 		}
 	}
 
+	//
+	String escapeprint(String s) {
+		StringBuffer b = new StringBuffer();
+
+		for(int i = 0; i < s.length(); i++) {
+			switch(s.charAt(i)) {
+			case '\n':  b.append("\\n");  break;
+			case '\r':  b.append("\\r");  break;
+			case '\t':  b.append("\\t");  break;
+			default:    b.append(s.charAt(i));  break;
+			}
+		}
+		return b.toString();
+	}
+
 	/**
 	 * 
 	 * @param state
@@ -133,6 +166,11 @@ implements NinaTranslator {
 		} else {
 			states.put(state, stateNo);
 			if(state.isAccepted())  accepts.add(stateNo);
+			if(state.isDead())      deads.add(stateNo);
+			if(state instanceof DBS &&
+					((DBS)state).isOnlyEmptyTransition()) {
+				emptyTransitions.add(stateNo);
+			}
 			trz.push(state);
 			return stateNo++;
 		}
@@ -166,10 +204,34 @@ implements NinaTranslator {
 	 * 
 	 * @return
 	 */
-	protected Iterable<Integer> acceptsIterable() {
+	protected int deadsSize() {
+		return deads.size();
+	}
+
+	/**
+	 * 
+	 * @return
+	 */
+	protected Set<Integer> acceptsIterable() {
 		return accepts;
 	}
 
+	/**
+	 * 
+	 * @return
+	 */
+	protected Set<Integer> deadsIterable() {
+		return deads;
+	}
+
+	/**
+	 * 
+	 * @return
+	 */
+	protected Set<Integer> emptyTransitionsIterable() {
+		return emptyTransitions;
+	}
+
 	/**
 	 * 
 	 * @param state
@@ -208,7 +270,7 @@ implements NinaTranslator {
 	 * 
 	 * @return
 	 */
-	protected NinatOptions getOptions() {
+	protected NinaInfo getOptions() {
 		return options;
 	}
 
@@ -269,6 +331,18 @@ implements NinaTranslator {
 	 */
 	public abstract void printAcceptStates(PrintStream out);
 
+	/**
+	 * 
+	 * @param out
+	 */
+	public abstract void printDeadStates(PrintStream out);
+
+	/**
+	 * 
+	 * @param out
+	 */
+	public abstract void printEmptyTransitionStates(PrintStream out);
+
 	/**
 	 * 
 	 * @param out
@@ -300,7 +374,8 @@ implements NinaTranslator {
 	 * @return
 	 * @throws IOException
 	 */
-	protected abstract InputStream openScript() throws IOException;
+	protected abstract InputStream openScript(
+			ShEnvironment env) throws IOException;
 
 	/**
 	 * 
@@ -341,6 +416,24 @@ implements NinaTranslator {
 	 */
 	protected abstract void printFinallyState(PrintStream out);
 
+	/**
+	 * 
+	 * @param out
+	 */
+	protected abstract void printInitTrap(PrintStream out);
+
+	/**
+	 * 
+	 * @param out
+	 */
+	protected abstract void printNFADeadState(PrintStream out);
+
+	/**
+	 * 
+	 * @param out
+	 */
+	protected abstract void printConstants(PrintStream out);
+
 	/**
 	 * 
 	 * @param ot
@@ -371,6 +464,32 @@ implements NinaTranslator {
 	 */
 	protected abstract void appendReturn(StringBuffer ot);
 
+	/**
+	 * 
+	 * @param ot
+	 * @param b
+	 */
+	protected abstract void appendYield(StringBuffer ot, String b);
+
+	/**
+	 * 
+	 * @param ot
+	 */
+	protected abstract String getConstName(String b);
+
+	/**
+	 * 
+	 * @param q
+	 * @return
+	 */
+	protected abstract LRTranslator getLRTranslator(Quadro q);
+
+	/**
+	 * 
+	 * @param env
+	 */
+	protected abstract void setLocalenv(Quadro q, ShEnvironment env);
+
 	//
 	private void printStateSize(String n, PrintStream out) {
 		out.printf("\t\t\treturn %d;\n", stateSize());
@@ -382,10 +501,12 @@ implements NinaTranslator {
 	 * @return
 	 */
 	@SuppressWarnings("unchecked")
-	public AbstractNinaTranslator prototype(String name, Object o) {
+	public AbstractNinaTranslator prototype(String name, Object o,
+			String s) {
 		AbstractNinaTranslator x;
 
 		x = newPrototype();
+		x.parent   = parent;
 		x.fragment = fragment;
 		x.machine  = machine;
 		x.options  = options;
@@ -395,6 +516,20 @@ implements NinaTranslator {
 		if(o instanceof DFABuilder) {
 			x.builder = (DFABuilder)o;
 			x.dfa = (DFA<Object, ?, Void>)x.builder.getMachine();
+		} else if(o instanceof NFABuilder) {
+			x.builder = (NFABuilder)o;
+			if(s == null || s.equals("int")) {
+				x.dfa = ConvertedRangeDFA.convertDFA(
+						(NinaNFA)x.builder.getMachine());
+			} else if(quadro.getType() == null) {
+				x.dfa = ConvertedRangeDFA.convertDFA(
+						(NinaNFA)x.builder.getMachine());
+			} else {
+				x.dfa = ConvertedDFA.convertDFA(
+						(NinaNFA)x.builder.getMachine());
+			}
+			// not minimize
+//			x.dfa = MinimizedRangeDFA.newInstance(x.dfa);
 		}
 		return x;
 	}
@@ -407,54 +542,6 @@ implements NinaTranslator {
 		}
 	}
 
-	//
-	private void processNFA(NinaNFA n, String p, Quadro q,
-			ShNinatBuiltInCommands cmd,
-			ShEnvironment env) throws IOException {
-		PrintStream ous = null;
-		InputStream ins = null;
-		ShFileSystem fs;
-		XtraceStream qs;
-		ShRuntime run;
-
-		if(q.getType() == null) {
-			dfa = ConvertedRangeDFA.convertDFA(n);
-		} else {
-			dfa = ConvertedDFA.convertDFA(n);
-		}
-
-		if(!options.getOption("minimize").equalsIgnoreCase("no")) {
-			dfa = MinimizedRangeDFA.newInstance(dfa);
-		}
-
-		try {
-			ins  = openScript();
-			ous  = openOutput();
-			fs   = new ShNinatFileSystem(fragment, q, options);
-			cmd.putCommand("print_token", new ShProcess() {
-
-				@Override
-				public int main(ShEnvironment env, ShFileSystem fs,
-						InputStream stdin, PrintStream stdout,
-						PrintStream stderr,
-						String... args) throws IOException {
-					printAcceptToken(stdout);
-					return 0;
-				}
-
-			});
-			run  = new DefaultShRuntime(cmd);
-			qs   = new XtraceStream(System.out);
-			ShFacade.execute(env, fs, cmd, run, ins, System.in, ous,
-					System.err, qs);
-		} catch(ShSyntaxException e) {
-			throw new RuntimeException(e);
-		} finally {
-			if(ins != null)  ins.close();
-			if(ous != null)  ous.close();
-		}
-	}
-
 	//
 	private AbstractNinaTranslator getsubfa(String[] args) {
 		if(args.length > 1) {
@@ -465,94 +552,23 @@ implements NinaTranslator {
 	}
 
 	//
-	private void processDFA(DFA<Object, Object, Void> d, String p,
-			Quadro q, ShNinatBuiltInCommands cmd,
-			ShEnvironment env) throws IOException {
+	private void process(String p, Quadro q,
+			ShNinatBuiltInCommands cmd, ShEnvironment env,
+			PrintStream ot) throws IOException {
+		ByteArrayOutputStream bos;
 		PrintStream ous = null;
 		InputStream ins = null;
 		ShFileSystem fs;
 		XtraceStream qs;
 		ShRuntime run;
 
-		dfa = d;
 		try {
-			ins  = openScript();
-			ous  = openOutput();
-			fs   = new ShNinatFileSystem(fragment, q, options);
-			cmd.putCommand("print_actions", new ShProcess() {
-
-				@Override
-				public int main(ShEnvironment env, ShFileSystem fs,
-						InputStream stdin, PrintStream stdout,
-						PrintStream stderr,
-						String... args) throws IOException {
-					getsubfa(args).printActions(stdout);
-					return 0;
-				}
-
-			});
-			cmd.putCommand("print_recover", new ShProcess() {
-
-				@Override
-				public int main(ShEnvironment env, ShFileSystem fs,
-						InputStream stdin, PrintStream stdout,
-						PrintStream stderr,
-						String... args) throws IOException {
-					getsubfa(args).printRecover(stdout);
-					return 0;
-				}
-
-			});
-			cmd.putCommand("print_deadstate", new ShProcess() {
-
-				@Override
-				public int main(ShEnvironment env, ShFileSystem fs,
-						InputStream stdin, PrintStream stdout,
-						PrintStream stderr,
-						String... args) throws IOException {
-					getsubfa(args).printDeadState(args[1], stdout);
-					return 0;
-				}
-
-			});
-			cmd.putCommand("print_statesize", new ShProcess() {
-
-				@Override
-				public int main(ShEnvironment env, ShFileSystem fs,
-						InputStream stdin, PrintStream stdout,
-						PrintStream stderr,
-						String... args) throws IOException {
-					getsubfa(args).printStateSize(args[1], stdout);
-					return 0;
-				}
-
-			});
-			cmd.putCommand("print_attrs", new ShProcess() {
-
-				@Override
-				public int main(ShEnvironment env, ShFileSystem fs,
-						InputStream stdin, PrintStream stdout,
-						PrintStream stderr,
-						String... args) throws IOException {
-					getsubfa(args).printAttrs(stdout);
-					return 0;
-				}
-
-			});
-			cmd.putCommand("print_finallystate", new ShProcess() {
-
-				@Override
-				public int main(ShEnvironment env, ShFileSystem fs,
-						InputStream stdin, PrintStream stdout,
-						PrintStream stderr,
-						String... args) throws IOException {
-					getsubfa(args).printFinallyState(stdout);
-					return 0;
-				}
-
-			});
-			run  = new DefaultShRuntime(cmd);
-			qs   = new XtraceStream(System.out);
+			ins = openScript(env);
+			bos = new ByteArrayOutputStream();
+			ous = new PrintStream(bos);
+			fs  = new ShNinatFileSystem(fragment, q, options);
+			run = new DefaultShRuntime(cmd);
+			qs  = new XtraceStream(System.out);
 			ShFacade.execute(env, fs, cmd, run, ins, System.in, ous,
 					System.err, qs);
 		} catch(ShSyntaxException e) {
@@ -561,26 +577,29 @@ implements NinaTranslator {
 			if(ins != null)  ins.close();
 			if(ous != null)  ous.close();
 		}
+
+		try {
+			ous = ot != null ? ot : openOutput();
+			ous.write(bos.toByteArray());
+			options.postprocess();
+		} finally {
+			if(ous != null)  ous.close();
+		}
 	}
 
 	private ShEnvironment getenv(String p, Quadro q,
-			Map<String, Object> sub) {
+			NinaSubautomata sub) {
 		ShEnvironment env;
 		StringBuffer b;
 		String s, d;
-		char[] a;
 
 		env  = new ShRootEnvironment();
-		a    = options.getOutputFilename().toCharArray();
-		a[0] = Character.toUpperCase(a[0]);
 		env.bind("IFS", " \t");
-		env.bind("CLASSNAME", new String(a));
+		env.bind("CLASSNAME", options.getClassName());
 		env.bind("PACKAGE", p);
 		env.bind("FILENAME", options.getFilename());
 		env.bind("OUTPUT_FILENAME", options.getOutputFilename());
-		s = (s = options.getOption("bufsize")).equals("") ?
-				"1024" : s;
-		env.bind("BUFSIZE", s);
+		env.bind("BUFSIZE", options.getBufSize());
 		env.bind("TEMPLATE", q.getOption("template"));
 		env.bind("EXTENDS", q.getOption("extends"));
 		env.bind("IMPLEMENTS", q.getOption("implements"));
@@ -597,8 +616,50 @@ implements NinaTranslator {
 		env.bind("ENABLE_MATCHER", q.getOption("enableMatcher"));
 		env.bind("ENABLE_LOG", q.getOption("enableLog"));
 		env.bind("API_ACCESS_MODIFIER",
-				q.getOption("APIAccessModifier"));
+				q.isOptionDefined("APIAccessModifier") ?
+						q.getOption("APIAccessModifier") + " " : "");
 		env.bind("READER", q.getOption("reader"));
+		env.bind("OWNER", q.getOptionNvl("owner", ""));
+		env.bind("YEAR", q.getOptionNvl("year",
+				YEAR.format(new java.util.Date())));
+		env.bind("ORGANIZATION", q.getOptionNvl("organization",
+				q.getOptionNvl("owner", "")));
+		env.bind("NEWLINEMODE",
+				"binary".equals(q.getOption("streammode")) ? "on" : "");
+		env.bind("READSLOW", q.getOptionBoolean("readSlow") ?
+				"true" : "");
+		env.bind("READSLEEP", q.getOptionInt("readSleep", -1) + "");
+		env.bind("EXEC_LOOKAHEAD",
+				q.getLanguageOption().getLookahead());
+		env.bind("EXEC_LOOKAHEAD_COMMIT",
+				q.getLanguageOption().getLookaheadCommit());
+		env.bind("TAPETYPE", q.getOption("tapetype"));
+
+		if("prompt".equals(q.getOption("main"))) {
+			env.bind("PUTPROMPT", "true");
+		} else if(q.isOptionDefined("main")) {
+			env.bind("PUTMAIN", "true");
+		}
+
+		if((s = q.getLicense()).trim().length() > 0) {
+			env.bind("LICENSE", "userlicense");
+		} else {
+			s = q.getOptionNvl("license", "default").toLowerCase();
+			env.bind("LICENSE", "/license/" + s);
+		}
+
+		if(q.isOptionDefined("enableIndent")) {
+			if((s = q.getType()) == null ||
+					s.equals("") ||
+					s.equals("char")) {
+				env.bind("ENABLE_INDENT", "true");
+			} else if((s = q.getLexerType()) != null &&
+					(s.equals("") || s.equals("char"))) {
+				env.bind("ENABLE_INDENT", "true");
+			} else {
+				throw new NinaException("indentnotsupported");
+			}
+		}
 
 		if((s = q.getType()) == null || s.equals("char")) {
 			env.bind("TYPE", "");
@@ -614,13 +675,53 @@ implements NinaTranslator {
 			env.bind("CTYPE", s);
 		}
 
+		if((s = q.getLexerType()) != null) {
+			env.bind("LEXER", q.getLexer());
+			if(s.equals("char")) {
+				env.bind("LTYPE", "");
+				env.bind("LCTYPE", "int");
+			} else if(s.equals("string")) {
+				env.bind("LTYPE", s);
+				env.bind("LCTYPE", "String");
+			} else if(s.equals("class")) {
+				env.bind("LTYPE", s);
+				env.bind("LCTYPE", "Object");
+			} else {
+				env.bind("LTYPE", s);
+				env.bind("LCTYPE", s);
+			}
+		}
+
 		b = new StringBuffer();  d = "";
-		for(String x : sub.keySet()) {
+		for(Map.Entry<String, Object> x : sub.entrySet()) {
+			if(x.getValue() instanceof DFABuilder) {
+				b.append(d).append(x.getKey());
+				d = " ";
+			}
+		}
+		env.bind("SUBAUTOMATA", b.toString());
+
+		b = new StringBuffer();  d = "";
+		for(String x : q.getLRObjects().keySet()) {
 			b.append(d).append(x);
 			d = " ";
 		}
-		env.bind("SUBAUTOMATA", b.toString());
-		return env;
+		env.bind("LRPARSERS", b.toString());
+		setLocalenv(q, env);
+		return new ShRootShellEnvironment(env);
+	}
+
+	private void setenv(ShEnvironment env, NinaAction builder) {
+		StringBuffer b;
+		String d;
+
+		b = new StringBuffer();  d = "";
+		for(String x : builder.getDynamicTransitMap().keySet()) {
+			b.append(d).append(x);
+			d = " ";
+		}
+		env.bind("DYNAMICAUTOMATA", b.toString());
+		if(b.length() > 0)  env.bind("ENABLE_LOOKAHEAD", "true");
 	}
 
 	/**
@@ -634,11 +735,13 @@ implements NinaTranslator {
 	 */
 	@SuppressWarnings("unchecked")
 	protected void translateQuadro(String name, Object o,
-			NinatOptions opts, Map<String, String> prms,
-			final Map<String, Object> sub) throws IOException {
+			NinaInfo opts, Map<String, String> prms,
+			final NinaSubautomata sub,
+			PrintStream ot) throws IOException {
 		ShNinatBuiltInCommands cmd;
 		ShEnvironment env;
 		String p, q, m;
+		NinaNFA n;
 
 		mainname = name;
 		subfas   = new HashMap<String, AbstractNinaTranslator>();
@@ -650,10 +753,7 @@ implements NinaTranslator {
 		}
 
 		fragment = quadro.getFragment();
-		if((p = opts.getOption("package")) != null &&
-				!p.equals("")) {
-			// do nothing
-		} else if((p = quadro.getRootPackage()) != null &&
+		if((p = quadro.getRootPackage()) != null &&
 				!p.equals("")) {
 			// do nothing
 		} else {
@@ -681,17 +781,21 @@ implements NinaTranslator {
 					PrintStream stderr,
 					String... args) throws IOException {
 				AbstractNinaTranslator t;
+				String s;
 
 				if(args.length > 1) {
-					t = prototype(args[1], sub.get(args[1]));
+					s = args.length > 2 ? args[2] : null;
+					t = prototype(args[1], sub.get(args[1]), s);
 					subfas.put(args[1], t);
 				} else {
 					t = AbstractNinaTranslator.this;
 				}
 
-				if(quadro.getType() == null) {
+				s = args.length > 2 ? args[2] : quadro.getType();
+				if(s == null || s.equals("") || s.equals("char") ||
+						s.equals("int")) {
 					t.printStates(stdout);
-				} else if(quadro.getType().equals("class")) {
+				} else if(s.equals("class")) {
 					t.printClassStates(stdout);
 				} else {
 					t.printObjectStates(stdout);
@@ -711,6 +815,30 @@ implements NinaTranslator {
 				return 0;
 			}
 
+		});
+		cmd.putCommand("print_deads", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printDeadStates(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_empty_transitions", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printEmptyTransitionStates(stdout);
+				return 0;
+			}
+
 		});
 		cmd.putCommand("print_imports", new ShProcess() {
 
@@ -736,18 +864,152 @@ implements NinaTranslator {
 				return 0;
 			}
 
+		});
+		cmd.putCommand("print_actions", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printActions(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_recover", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printRecover(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_deadstate", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printDeadState(args[1], stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_statesize", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printStateSize(args[1], stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_attrs", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printAttrs(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_finallystate", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printFinallyState(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_inittrap", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				printInitTrap(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_constants", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printConstants(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_token", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printAcceptToken(stdout);
+				return 0;
+			}
+
+		});
+		cmd.putCommand("print_nfadead", new ShProcess() {
+
+			@Override
+			public int main(ShEnvironment env, ShFileSystem fs,
+					InputStream stdin, PrintStream stdout,
+					PrintStream stderr,
+					String... args) throws IOException {
+				getsubfa(args).printNFADeadState(stdout);
+				return 0;
+			}
+
 		});
 
 		if(o instanceof NFABuilder) {
 			machine = "nfa";
 			builder = (NFABuilder)o;
-			processNFA((NinaNFA)builder.getMachine(), p, quadro, cmd,
-					env);
+			n = (NinaNFA)builder.getMachine();
+			if(quadro.getType() == null) {
+				dfa = ConvertedRangeDFA.convertDFA(n);
+			} else {
+				dfa = ConvertedDFA.convertDFA(n);
+			}
+			// not minimize
+//			dfa = MinimizedRangeDFA.newInstance(dfa);
+			process(p, quadro, cmd, env, ot);
 		} else if(o instanceof DFABuilder) {
 			machine = "dfa";
 			builder = (DFABuilder)o;
-			processDFA((DFA<Object, Object, Void>)builder.getMachine(),
-					p, quadro, cmd, env);
+			setenv(env.getEnvironment(), builder);
+			dfa = (DFA<Object, Object, Void>)builder.getMachine();
+			getLRTranslator(quadro).setCommands(cmd);
+			process(p, quadro, cmd, env, ot);
+		} else if(o instanceof TMBuilder) {
+			machine = "tm";
+			builder = (TMBuilder)o;
+			dfa = (DFA<Object, Object, Void>)builder.getMachine();
+			process(p, quadro, cmd, env, ot);
 		} else {
 			opts.perror("machinenotsupport", m);
 		}
@@ -757,19 +1019,20 @@ implements NinaTranslator {
 	 * @see net.morilib.nina.compiler.NinaTranslater#translate(java.io.Reader, java.io.PrintWriter)
 	 */
 	@Override
-	public void translate(String name, Reader rd, NinatOptions opts,
-			Map<String, String> prms) throws IOException {
-		Map<String, Object> s;
+	public void translate(String name, Reader rd, NinaInfo opts,
+			List<String> libs, Map<String, String> prms,
+			PrintStream ot) throws IOException {
+		NinaSubautomata s;
 		String n;
 		Object o;
 
-		s = new HashMap<String, Object>();
-		n = Nina.getFAName(name);
+		n = Nina.getFAName(null, name);
+		s = new NinaSubautomata(n);
 		s.put(n, null);
-		quadro = Quadro.read(n, rd);
-		o = NinaParser.complie(quadro, opts.getLibraryList(), prms, s,
-				opts.getConsole());
-		translateQuadro(n, o, opts, prms, s);
+		quadro = Quadro.read(n, rd, libs);
+		o = NinaParser.complie(quadro, libs, prms, s,
+				opts.getConsole(), opts);
+		translateQuadro(n, o, opts, prms, s, ot);
 	}
 
 	/* (non-Javadoc)
@@ -777,17 +1040,18 @@ implements NinaTranslator {
 	 */
 	@Override
 	public Object compile(String name, Reader rd, NinatOptions opts,
+			List<String> libs,
 			Map<String, String> prms) throws IOException {
-		Map<String, Object> s;
+		NinaSubautomata s;
 		Quadro q;
 		String n;
 
-		s = new HashMap<String, Object>();
-		n = Nina.getFAName(name);
+		n = Nina.getFAName(null, name);
+		s = new NinaSubautomata(n);
 		s.put(n, null);
-		q = Quadro.read(n, rd);
+		q = Quadro.read(n, rd, libs);
 		return NinaParser.complie(q, opts.getLibraryList(), prms, s,
-				opts.getConsole());
+				opts.getConsole(), opts);
 	}
 
 }
