@@ -59,6 +59,14 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		parent = this;
 	}
 
+	//
+	private int infimumbound(Interval a) {
+		Object o;
+
+		o = a.getInfimumBound();
+		return o == Interval.FROM_INFIMUM ? 0 : ((Integer)o).intValue();
+	}
+
 	//
 	private int getDeadStateNo() {
 		Object s;
@@ -95,6 +103,11 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		return x;
 	}
 
+	//
+	private boolean isLookahead(Object o) {
+		return o != null && o.toString().startsWith(LOK);
+	}
+
 	//
 	private void printintv(PrintStream out, Interval v, boolean els,
 			Object o) {
@@ -128,6 +141,13 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		return "\t";
 	}
 
+	//
+	private void printNextStep(PrintStream out,
+			DFAState<Object, ?, Void> d) {
+		out.format("\t\t\t__this__->state = %d;\n", getStateNo(d));
+		out.println("\t\t\treturn 1;");
+	}
+
 	//
 	private boolean printDynamicTransition(PrintStream out,
 			DFAState<Object, ?, Void> dfa, boolean els) {
@@ -198,24 +218,47 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 	private void printState(PrintStream out,
 			DFAState<Object, ?, Void> dfa) {
 		boolean els = false;
-		DFAState<Object, ?, Void> d;
 		int sn = getStateNo(dfa), c;
 		DFABuilder.DBS a, b;
 		TMBuilder.DBS x;
-		Object o;
+		Set<String> k;
 		String s, t;
+		Object o;
 
 		out.format("\tcase %d:\n", sn);
+
+		// if the state has only empty transition
+		if(dfa instanceof DFABuilder.DBS &&
+				((DFABuilder.DBS)dfa).isOnlyEmptyTransition()) {
+			out.format("\t\t__this__->state = %d;\n",
+					getStateNo(((DFABuilder.DBS)dfa).getOthers()));
+			out.println("\t\treturn 1;");
+			return;
+		}
+
+		// with lookahead
 		for(Interval v : dfa.getAlphabetRanges()) {
-			c = ((Integer)v.getInfimumBound()).intValue();
+			if(v.isEmpty())  continue;
+			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
+			if(!isLookahead(o = dfa.getLabelInt(c)))  continue;
+
 			printintv(out, v, els, o = dfa.getLabelInt(c));
 			printIntervalAction(out, dfa, o);
+			printNextStep(out, dfa.goInt(c));
+			els = true;
+		}
 
-			// print next step
-			d = dfa.goInt(c);
-			out.format("\t\t\t__this__->state = %d;\n", getStateNo(d));
-			out.println("\t\t\treturn 1;");
+		// without lookahead
+		for(Interval v : dfa.getAlphabetRanges()) {
+			if(v.isEmpty())  continue;
+			c = infimumbound(v);
+			if(v.isInfimumOpen())  c++;
+			if(isLookahead(o = dfa.getLabelInt(c)))  continue;
+
+			printintv(out, v, els, o = dfa.getLabelInt(c));
+			printIntervalAction(out, dfa, o);
+			printNextStep(out, dfa.goInt(c));
 			els = true;
 		}
 
@@ -241,6 +284,24 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 			els = true;
 		}
 
+		// put user edges
+		if(dfa instanceof DFABuilder.DBS &&
+				(k = ((DFABuilder.DBS)dfa).getUserEdges()) != null) {
+			for(String v : k) {
+				b = ((DFABuilder.DBS)dfa).getUserEdge(v);
+				o = ((DFABuilder.DBS)dfa).getUserMealyEdge(v);
+				if(els) {
+					out.printf("\t\t} else if(%s) {\n", v);
+				} else {
+					out.printf("\t\tif(%s) {\n", v);
+				}
+				printIntervalAction(out, dfa, o);
+				out.format("\t\t\t__this__->state = %d;\n", getStateNo(b));
+				out.format("\t\t\treturn 1;\n");
+				els = true;
+			}
+		}
+
 		// put others
 		if(dfa instanceof TMBuilder.DBS) {
 			if((x = ((TMBuilder.DBS)dfa).getOthers()) != null) {
@@ -329,17 +390,14 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		throw new NinaException("unsupportedclasstype", "C");
 	}
 
-	/* (non-Javadoc)
-	 * @see net.morilib.nina.translate.AbstractNinaTranslator#printAcceptStates(java.io.PrintStream)
-	 */
-	@Override
-	public void printAcceptStates(PrintStream out) {
+	//
+	private void printPStates(PrintStream out, Set<Integer> a) {
 		String d = "\treturn (";
 
-		if(acceptsSize() == 0) {
+		if(a.size() == 0) {
 			out.println("\treturn 0;");
 		} else {
-			for(Integer i : acceptsIterable()) {
+			for(Integer i : a) {
 				out.print(d);
 				out.format("__this__->state == %d", i);
 				d = " ||\n\t\t\t";
@@ -348,6 +406,30 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		}
 	}
 
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.translate.AbstractNinaTranslator#printAcceptStates(java.io.PrintStream)
+	 */
+	@Override
+	public void printAcceptStates(PrintStream out) {
+		printPStates(out, acceptsIterable());
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.translate.AbstractNinaTranslator#printDeadStates(java.io.PrintStream)
+	 */
+	@Override
+	public void printDeadStates(PrintStream out) {
+		printPStates(out, deadsIterable());
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.translate.AbstractNinaTranslator#printEmptyTransitionStates(java.io.PrintStream)
+	 */
+	@Override
+	public void printEmptyTransitionStates(PrintStream out) {
+		printPStates(out, emptyTransitionsIterable());
+	}
+
 	/* (non-Javadoc)
 	 * @see net.morilib.nina.translate.AbstractNinaTranslator#printAcceptToken(java.io.PrintStream)
 	 */
@@ -623,13 +705,21 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 	 * @see net.morilib.nina.translate.AbstractNinaTranslator#openScript()
 	 */
 	@Override
-	protected InputStream openScript() {
+	protected InputStream openScript(ShEnvironment env) {
 		return NinaTranslator.class.getResourceAsStream(
 				"/net/morilib/nina/translate/nina_template." +
 				getMachine() +
 				".c.sh");
 	}
 
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.translate.NinaTranslator#getExtension()
+	 */
+	@Override
+	public String getExtension() {
+		return ".c";
+	}
+
 	/* (non-Javadoc)
 	 * @see net.morilib.nina.translate.AbstractNinaTranslator#openOutput()
 	 */
@@ -639,7 +729,8 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 
 		s = getOptions().getOutputDir();
 		return new PrintStream(getOptions().getOutputStream(
-				s, getOptions().getOutputFilename() + ".c"), true);
+				s, getOptions().getOutputFilename() + getExtension()),
+				true);
 	}
 
 	/* (non-Javadoc)
