@@ -59,6 +59,14 @@ public class NinaTranslatorCSharp extends AbstractNinaTranslator {
 		parent = this;
 	}
 
+	//
+	private int infimumbound(Interval a) {
+		Object o;
+
+		o = a.getInfimumBound();
+		return o == Interval.FROM_INFIMUM ? 0 : ((Integer)o).intValue();
+	}
+
 	//
 	private String tostr(int c) {
 		String x;
@@ -308,6 +316,13 @@ public class NinaTranslatorCSharp extends AbstractNinaTranslator {
 		}
 	}
 
+	//
+	private void printNextStep(PrintStream out,
+			DFAState<Object, ?, Void> d) {
+		out.format("\t\t\t\t__this__.STATE = %d;\n", getStateNo(d));
+		out.println("\t\t\t\treturn 1;");
+	}
+
 	//
 	private boolean printDynamicTransition(PrintStream out,
 			DFAState<Object, ?, Void> dfa, boolean els) {
@@ -375,7 +390,6 @@ public class NinaTranslatorCSharp extends AbstractNinaTranslator {
 	private void printState(PrintStream out,
 			DFAState<Object, ?, Void> dfa) {
 		boolean els = false;
-		DFAState<Object, ?, Void> d;
 		int sn = getStateNo(dfa), c;
 		Object o;
 
@@ -390,16 +404,29 @@ public class NinaTranslatorCSharp extends AbstractNinaTranslator {
 			return;
 		}
 
+		// with lookahead
 		for(Interval v : dfa.getAlphabetRanges()) {
-			c = ((Integer)v.getInfimumBound()).intValue();
+			if(v.isEmpty())  continue;
+			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
+			if(!isLookahead(o = dfa.getLabelInt(c)))  continue;
+
 			printintv(out, v, els, o = dfa.getLabelInt(c));
 			printIntervalAction(out, dfa, o);
+			printNextStep(out, dfa.goInt(c));
+			els = true;
+		}
 
-			// print next step
-			d = dfa.goInt(c);
-			out.format("\t\t\t\t__this__.STATE = %d;\n", getStateNo(d));
-			out.println("\t\t\t\treturn 1;");
+		// without lookahead
+		for(Interval v : dfa.getAlphabetRanges()) {
+			if(v.isEmpty())  continue;
+			c = infimumbound(v);
+			if(v.isInfimumOpen())  c++;
+			if(isLookahead(o = dfa.getLabelInt(c)))  continue;
+
+			printintv(out, v, els, o = dfa.getLabelInt(c));
+			printIntervalAction(out, dfa, o);
+			printNextStep(out, dfa.goInt(c));
 			els = true;
 		}
 
