@@ -72,6 +72,11 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 		return Integer.toString(c);
 	}
 
+	//
+	private boolean isLookahead(Object o) {
+		return o != null && o.toString().startsWith(LOK);
+	}
+
 	//
 	private void printintv(PrintStream out, Interval v, boolean els,
 			Object o) {
@@ -293,6 +298,13 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 		}
 	}
 
+	//
+	private void printNextStep(PrintStream out,
+			DFAState<Object, ?, Void> d) {
+		out.format("\t\t\tSTATE = %d;\n", getStateNo(d));
+		out.println("\t\t\treturn 1;");
+	}
+
 	//
 	private boolean printDynamicTransition(PrintStream out,
 			DFAState<Object, ?, Void> dfa, boolean els) {
@@ -355,7 +367,6 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 	private void printState(PrintStream out,
 			DFAState<Object, ?, Void> dfa) {
 		boolean els = false;
-		DFAState<Object, ?, Void> d;
 		int sn = getStateNo(dfa), c;
 		Object o;
 
@@ -370,17 +381,29 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 			return;
 		}
 
+		// with lookahead
 		for(Interval v : dfa.getAlphabetRanges()) {
 			if(v.isEmpty())  continue;
 			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
+			if(!isLookahead(o = dfa.getLabelInt(c)))  continue;
+
 			printintv(out, v, els, o = dfa.getLabelInt(c));
 			printIntervalAction(out, dfa, o);
+			printNextStep(out, dfa.goInt(c));
+			els = true;
+		}
 
-			// print next step
-			d = dfa.goInt(c);
-			out.format("\t\t\tSTATE = %d;\n", getStateNo(d));
-			out.println("\t\t\treturn 1;");
+		// without lookahead
+		for(Interval v : dfa.getAlphabetRanges()) {
+			if(v.isEmpty())  continue;
+			c = infimumbound(v);
+			if(v.isInfimumOpen())  c++;
+			if(isLookahead(o = dfa.getLabelInt(c)))  continue;
+
+			printintv(out, v, els, o = dfa.getLabelInt(c));
+			printIntervalAction(out, dfa, o);
+			printNextStep(out, dfa.goInt(c));
 			els = true;
 		}
 
